@@ -13,7 +13,7 @@ from tornado import iostream
 from tornado.options import options
 
 from blackhole.state import MailState
-from blackhole.data import response
+from blackhole.data import response, EHLO_RESPONSES
 from blackhole.opts import ports
 from blackhole.ssl_utils import sslkwargs
 from blackhole.log import log
@@ -44,7 +44,7 @@ def sockets():
             sock.bind((options.host, port))
             sock.listen(5)
             socks[s] = sock
-        except socket.error, e:
+        except socket.error as e:
             if e.errno == 13:
                 log.error("Permission denied, could not bind to %s:%s" %
                           (options.host, port))
@@ -66,7 +66,7 @@ def connection_stream(connection):
     if connection.getsockname()[1] == options.ssl_port and options.ssl:
         try:
             ssl_connection = ssl.wrap_socket(connection, **sslkwargs)
-        except (ssl.SSLError, socket.error), e:
+        except (ssl.SSLError, socket.error) as e:
             if e.errno == ssl.SSL_ERROR_EOF or e.errno == errno.ECONNABORTED:
                 ssl_connection.close()
                 return
@@ -75,7 +75,7 @@ def connection_stream(connection):
         # Do a nasty blanket Exception until SSL exceptions are fully known
         try:
             return iostream.SSLIOStream(ssl_connection)
-        except Exception, e:
+        except Exception as e:
             log.error(e)
             ssl_connection.close()
             return
@@ -98,9 +98,18 @@ def handle_command(line, mail_state):
         if line[0] == "." and len(line) == 3 and ord(line[0]) == 46:
             mail_state.reading = False
             resp = response()
-    elif any(line.lower().startswith(e) for e in ['helo', 'ehlo',
-                                                  'mail from',
-                                                  'rcpt to', 'rset']):
+    elif line.lower().startswith("ehlo"):
+        resp = ["%s\n" % x for x in EHLO_RESPONSES]
+    elif any(line.lower().startswith(e) for e in ['helo', 'mail from',
+                                                  'rcpt to', 'noop']):
+        resp = response(250)
+    elif line.lower().startswith("rset"):
+        new_id = email_id()
+        log.debug("[%s] RSET received, changing ID to [%s]" %
+                  (mail_state.email_id, new_id))
+        # Reset mail state
+        mail_state.reading = False
+        mail_state.email_id = new_id
         resp = response(250)
     elif line.lower().startswith("starttls"):
         resp = response(220)
@@ -117,6 +126,12 @@ def handle_command(line, mail_state):
     return resp, close
 
 
+def write_response(stream, mail_state, resp):
+    """Write the response back to the stream"""
+    log.debug("[%s] SEND: %s" % (mail_state.email_id, resp.rstrip()))
+    stream.write(resp)
+
+
 def connection_ready(sock, fd, events):
     """
     Accepts the socket connections and passes them off
@@ -129,7 +144,7 @@ def connection_ready(sock, fd, events):
     while True:
         try:
             connection, address = sock.accept()
-        except socket.error, e:
+        except socket.error as e:
             if e.errno not in (errno.EWOULDBLOCK, errno.EAGAIN):
                 raise
             return
@@ -154,8 +169,14 @@ def connection_ready(sock, fd, events):
             log.debug("[%s] RECV: %s" % (mail_state.email_id, line.rstrip()))
             resp, close = handle_command(line, mail_state)
             if resp:
-                log.debug("[%s] SEND: %s" % (mail_state.email_id, resp.rstrip()))
-                stream.write(resp)
+                if isinstance(resp, list):
+                    # This is required for returning
+                    # multiple status codes for EHLO
+                    for r in resp:
+                        write_response(stream, mail_state, r)
+                else:
+                    # Otherwise it's a single response
+                    write_response(stream, mail_state, resp)
             if close is True:
                 log.debug("Closing")
                 stream.close()
