@@ -1,7 +1,7 @@
 """blackhole.state - State object for the current connection."""
 
 
-class MailState():
+class MailState(object):
     """A state object used for remembering
     the current connections place in our runtime.
 
@@ -10,6 +10,7 @@ class MailState():
     DATA command.
     """
     _reading_data = False
+    _email_id = None
 
     @property
     def reading(self):
@@ -31,3 +32,28 @@ class MailState():
         """Property for deleting self.reading"""
         # This shouldn't be called or need to be called
         del self._reading_data
+
+    @property
+    def email_id(self):
+        """
+        Email ID is used to assign commands
+        sent and received against an email/connection
+        ID.
+
+        Only utilized when debug flag is set.
+        """
+        return self._email_id
+
+    @email_id.setter
+    def email_id(self, val):
+        """
+        Set email_id
+
+        'val' is a hexidecimal string.
+        """
+        self._email_id = val
+
+    @email_id.deleter
+    def email_id(self):
+        """Reset email_id back to None."""
+        self.email_id = None
